@@ -27,7 +27,8 @@ covariates <- character()               # control variables
 R <- 100                                # number of bootstrap samples
 level <- c(0.9, 0.95)                   # confidence level
 ci_type <- "perc"                       # type of confidence intervals
-ctrl <- reg_control(efficiency = 0.95)  # for MM-regression estimator
+robust_ctrl <- MM_reg_control(efficiency = 0.95)     # for MM-regression
+median_ctrl <- median_reg_control(algorithm = "fn")  # for median regression
 
 ## perform bootstrap tests
 boot_list <- list(
@@ -35,13 +36,14 @@ boot_list <- list(
     set.seed(seed)
     test_mediation(test_data, x = x, y = y, m = m, covariates = covariates,
                    test = "boot", R = R, level = level[1], type = ci_type,
-                   method = "regression", robust = TRUE, control = ctrl)
+                   method = "regression", robust = TRUE, control = robust_ctrl)
   },
   median = {
     set.seed(seed)
     test_mediation(test_data, x = x, y = y, m = m, covariates = covariates,
                    test = "boot", R = R, level = level[1], type = ci_type,
-                   method = "regression", robust = "median")
+                   method = "regression", robust = "median",
+                   control = median_ctrl)
   },
   # skewnormal = {
   #   set.seed(seed)
@@ -123,10 +125,10 @@ for (method in methods) {
     # robust or nonrobust fit and test
     if (method == "robust") {
       expect_identical(boot$fit$robust, "MM")
-      expect_equal(boot$fit$control, ctrl)
+      expect_equal(boot$fit$control, robust_ctrl)
     } else if (method == "median") {
       expect_identical(boot$fit$robust, "median")
-      expect_null(boot$fit$control)
+      expect_equal(boot$fit$control, median_ctrl)
     } else {
       expect_false(boot$fit$robust)
       expect_null(boot$fit$control)
